@@ -3,11 +3,18 @@ from margument.log import throw
 
 class SettingsProcessor:
     def __init__(self, settings, args_parser):
+        """
+        :param settings: A list of settings to be processed.
+        :param args_parser: the instance from argsparse.ArgumentParser() previously created
+        """
         self.settings = settings
         self.args_parser = args_parser
 
     def run(self):
-
+        """
+        This method will iterate through all the given settings and will process each one according to their specifications.
+        :return: A dictionary of all settings given each containing a list of all parsed configurations from the user and/or the external file .
+        """
         for setting in self.settings:
             setting.program_arguments.add_arguments(self.args_parser)
 
